#
# spec file for package xfce4-cpugraph-plugin
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.14.0
%define plugin cpugraph
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.2.2
Release:        bp153.1.10
Summary:        CPU Graph Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-cpugraph-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.2/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxfce4panel-2.0)
BuildRequires:  pkgconfig(libxfce4ui-2)
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The CPU Graph plugin diplays a customizable graph of the CPU load of either
a specific CPU or all CPUs combined.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libcpugraph.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS ChangeLog NEWS README
%{!?with_git:%doc AUTHORS NEWS README}
%license COPYING
%{_libdir}/xfce4/panel/plugins/libcpugraph.so
%{_datadir}/xfce4/panel/plugins/cpugraph.desktop
%{_datadir}/icons/hicolor/*/apps/xfce4-cpugraph-plugin.png

%files lang -f %{name}.lang

%changelog
* Sun Feb 14 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.2.2
  * Record CPU load data even if the chart is currently disabled
  * Validate size against minimum and maximum allowed values
  * Change semantics of the non-linear time-scale mode
  * Fix corner cases when rendering the grid and LED modes
  * Show SMT stats tooltip only when needed
  * Translation Updates
* Sun Jan 31 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.2.1
  * Repaint CPU load history after the user changes the update interval
  * Properly initialize current usage bars
  * Scale CPU load history chart according to the current update interval
  * Store history in a circular buffer
  * Add timestamps to CPU load history
  * Update copyright year
  * Update configuration files
  * Translation Updates
* Mon Dec 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.2.0
  * Highlighting of suboptimal thread placement on SMT CPUs
  * Separate the associated command from the rest of config options
  * Better resilience to inconsistent OS CPU utilization data
  * Display 'Show bars' in the same tab as 'Bars color'
  * Clamp CPU usage values to zero if they are below a threshold
  * Cleanup NEWS file
  * Use larger unscaled icon in about dialog
  * Add small explanation about default commands
  * Dynamic default command lookup
  * Fix RGBA string memory leak
  * Fix an invalid memory reference
  * Link sensitivity of labels to sensitivity of color buttons
  * Allow setting colors with alpha
  * Revalidate the event box after showing widgets
  * Use floating-point instead of fixed-point CPU load values
  * Paint CPU usage if it is 1 pixel tall
  * Lower CPU usage when rendering bars
  * Update URLs
  * Improve performance of CPU data parsing
  * Read CPU data correctly if some CPUs are offline
    (gxo#panel-plugins/xfce4-cpugraph-plugin!7)
  * Paint CPU bars in left-to-right order
  * Separate the bars from the history frame
  * Fix old-style function warnings
  * Fix clang and gcc warnings
  * Also offer a 3 second update interval
    (gxo#panel-plugins/xfce4-cpugraph-plugin#9)
  * Update URLs from goodies.x.o to docs.x.o (bxo#16157)
  * Allow compilation with panel 4.15
  * Fix typo breaking build on NetBSD (bxo#15794)
  * Disable frame and make background transparent by default
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
* Wed Jul  3 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.1.0
  * Stable release of cpugraph-plugin, featuring only updated
    translations. For more details on the GTK 3 Port and other
    improvements, please refer to the release notes of 1.0.90
    and 1.0.91.
* Sun Jun 23 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- update to version 1.0.91
  * Add option to disable the graph (bxo#15163)
  * Use css to change bar colors (bxo#15186)
  * Fix bars in horizontal mode
  * Updated translations
* Wed May 29 2019 Vinzenz Vietzke <vinz@vinzv.de>
- update to version 1.0.90
  - GTK 3 Port
  - Updated translations
- Cleaned spec file (URLs with https, Git bcond)
* Sun Mar 17 2013 gber@opensuse.org
- update to version 1.0.5
  - only set bar color if a color was actually specified
  - only set bar color if bars are enabled
- dropped obsolete
  xfce4-panel-plugin-cpugrap-only-set-color-if-enabled.patch
* Mon Jul  2 2012 gber@opensuse.org
- update to version 1.0.4
  - fix build failure with xfce4-panel 4.8
- added xfce4-panel-plugin-cpugrap-only-set-color-if-enabled.patch
  in order to only set bar color if bars are enabled (bxo#907,
  backported from upstream git)
* Sun Jul  1 2012 gber@opensuse.org
- update to version 1.0.3
  - better compliance with panel plugin HIG
  - add an option allowing to set the bar color
  - fix transparency issues
* Sun Apr 29 2012 gber@opensuse.org
- update to version 1.0.2
  - ported to libxfce4ui
  - fixed buffer overflow
  - fixes plugin losing associated command value
  - build the plugin as a module
  - adapt to panel 4.9 api
- removed obsolete
  xfce4-panel-plugin-cpugraph-1.0.1-fix-buffer-overflow.patch
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
